@@ -98,8 +98,8 @@ def consistent_times(self, attempt_fix=True, raise_errors=True):
     elif time is not None and len(time):
         self['time'] = time
         self['ids_properties']['homogeneous_time'] = extra_info['homogeneous_time']
-    elif attempt_fix and ds in ['dataset_description', 'wall']:
-        self['time'] = [0.0]
+    elif attempt_fix:
+        self['time'] = [-1.0]
         extra_info['homogeneous_time'] = True
         self['ids_properties']['homogeneous_time'] = extra_info['homogeneous_time']
         return None
@@ -244,7 +244,6 @@ def summary_greenwald(ods, update=True):
 @add_to__ODS__
 @preprocess_ods('core_profiles', 'equilibrium')
 def summary_lineaverage_density(ods, line_grid=2000, time_index=None, update=True):
-
     """
     Calculates line-average electron density for each time slice and stores them in the summary ods
 
@@ -1254,6 +1253,37 @@ def equilibrium_transpose_RZ(ods, flip_dims=False):
     return ods
 
 
+@add_to__ODS__
+@preprocess_ods('magnetics')
+def magnetics_sanitize(ods, remove_bpol_probe=True):
+    '''
+    Take data in legacy magnetics.bpol_probe and store it in current magnetics.b_field_pol_probe and magnetics.b_field_tor_probe
+
+    :param ods: ODS to update in-place
+
+    :return: updated ods
+    '''
+    if 'magnetics.bpol_probe' not in ods:
+        return ods
+
+    if 'magnetics.b_field_pol_probe' in ods:
+        ods['magnetics.b_field_pol_probe'].clear()
+    if 'magnetics.b_field_tor_probe' in ods:
+        ods['magnetics.b_field_tor_probe'].clear()
+
+    tor_angle = ods['magnetics.bpol_probe[:].toroidal_angle']
+    for k in ods['magnetics.bpol_probe']:
+        if abs(numpy.sin(ods.get(f'magnetics.bpol_probe.{k}.toroidal_angle', 0.0))) < numpy.sin(numpy.pi / 4):
+            ods[f'magnetics.b_field_pol_probe.+'] = ods['magnetics.bpol_probe'][k]
+        else:
+            ods[f'magnetics.b_field_tor_probe.+'] = ods['magnetics.bpol_probe'][k]
+
+    if remove_bpol_probe:
+        del ods['magnetics.bpol_probe']
+
+    return ods
+
+
 def delete_ggd(ods, ds=None):
     """
     delete all .ggd and .grids_ggd entries
@@ -1393,6 +1423,46 @@ def check_iter_scenario_requirements(ods):
     return fail
 
 
+@add_to__ALL__
+def probe_endpoints(r0, z0, a0, l0, cocos):
+    '''
+    Transform r,z,a,l arrays commonly used to describe poloidal magnetic
+    probes geometry to actual r,z coordinates of the end-points of the probes.
+    This is useful for plotting purposes.
+
+    :param r0: r coordinates [m]
+
+    :param z0: Z coordinates [m]
+
+    :param a0: poloidal angles [radiants]
+
+    :param l0: lenght [m]
+
+    :param cocos: cocos convention
+
+    :return: list of 2-points r and z coordinates of individual probes
+    '''
+    theta_convention = 1
+    if cocos in [1, 4, 6, 7, 11, 14, 16, 17]:
+        theta_convention = -1
+
+    boo = (1 - numpy.sign(l0)) / 2.0
+    cor = boo * numpy.pi / 2.0
+    # then, compute the two-point arrays to build the partial rogowskis
+    # as segments rather than single points, applying the correction
+    px = r0 - l0 / 2.0 * numpy.cos(theta_convention * (a0 + cor))
+    py = z0 - l0 / 2.0 * numpy.sin(theta_convention * (a0 + cor))
+    qx = r0 + l0 / 2.0 * numpy.cos(theta_convention * (a0 + cor))
+    qy = z0 + l0 / 2.0 * numpy.sin(theta_convention * (a0 + cor))
+    segx = []
+    segy = []
+    for k in range(len(r0)):
+        segx.append([px[k], qx[k]])
+        segy.append([py[k], qy[k]])
+
+    return segx, segy
+
+
 @add_to__ALL__
 def transform_current(rho, JtoR=None, JparB=None, equilibrium=None, includes_bootstrap=False):
     """
@@ -1894,6 +1964,9 @@ def generate_cocos_signals(structures=[], threshold=0, write=True, verbose=False
 
     :return: dictionary structure with tally of score and reason for scoring for every entry
     """
+    # cocos_signals contains the IMAS locations and the corresponding `cocos_transform` function
+    from .omas_cocos import _cocos_signals
+
     # update OMAS cocos information with the one stored in IMAS
     from .omas_structure import extract_cocos
 
@@ -1980,35 +2053,37 @@ _cocos_signals = {}
 """
         ]
 
+        skip_signals = [
+            'chi_squared',
+            'standard_deviation',
+            'weight',
+            'coefficients',
+            'beta_tor',
+            'beta_pol',
+            'radial',
+            'rho_tor_norm',
+            'darea_drho_tor',
+            'dvolume_drho_tor',
+            'ratio',
+            'fraction',
+            'rate',
+            'd',
+            'flux',
+            'v',
+            'b_field_max',
+            'b_field_r',
+            'b_field_z',
+            'b_r',
+            'b_z',
+            'width_tor',
+        ]
+
         # loop over structures
         for structure in structures:
             print('Updating COCOS info for: ' + structure)
             text.extend(['', '# ' + structure.upper()])
             csig.extend(['', '# ' + structure.upper()])
 
-            skip_signals = [
-                'chi_squared',
-                'standard_deviation',
-                'weight',
-                'coefficients',
-                'r',
-                'z',
-                'beta_tor',
-                'beta_pol',
-                'radial',
-                'rho_tor_norm',
-                'darea_drho_tor',
-                'dvolume_drho_tor',
-                'ratio',
-                'fraction',
-                'rate',
-                'd',
-                'flux',
-                'v',
-                'b_field_max',
-                'width_tor',
-            ]
-
             out[structure] = {}
             ods[structure]
             m = 0
@@ -2034,6 +2109,8 @@ _cocos_signals = {}
                     elif units in [None, 's']:
                         out[structure].setdefault(-1, []).append((item, '[%s]' % units))
                         continue
+                    elif re.match('.*\.[rz]$', item):
+                        continue
                     elif any([(item_.endswith('.' + k) or item_.endswith('_' + k) or '.' + k + '.' in item) for k in skip_signals]):
                         out[structure].setdefault(-1, []).append((item, p2l(item_)[-1]))
                         continue
@@ -2042,7 +2119,7 @@ _cocos_signals = {}
                         continue
                     n = item.count('.')
                     for pnt, key in enumerate(p2l(item)):
-                        pnt = pnt / float(n)
+                        pnt = pnt / n
                         for case in ['q', 'ip', 'b0', 'phi', 'psi', 'f', 'f_df']:
                             if key == case:
                                 rationale += [case]
@@ -2122,20 +2199,31 @@ _cocos_signals = {}
         _extra_structures.update(_extra_structures_bkp)
 
 
-# cocos_signals contains the IMAS locations and the corresponding `cocos_transform` function
-from .omas_cocos import _cocos_signals
-
-
 # The CocosSignals class is just a dictionary that raises warnings when users access
 # entries that are likely to need a COCOS transformation, but do not have one.
 class CocosSignals(dict):
+    def __init__(self):
+        self.reload()
+
     def __getitem__(self, key):
         value = dict.__getitem__(self, key)
         if value == '?':
-            warnings.warn('`%s` may require defining its COCOS transform in omas/omas_cocos.py' % key)
+            warnings.warn(
+                f'''
+`{key}` may require defining its COCOS transform in {os.path.split(__file__)[0] + os.sep}omas_cocos.py
+Once done, you can reload the cocos definitions with:
+> from omas.omas_physics import cocos_signals; cocos_signals.reload()
+'''.strip()
+            )
         return value
 
+    def reload(self):
+        namespace = {}
+        with open(os.path.split(__file__)[0] + os.sep + 'omas_cocos.py', 'r') as f:
+            exec(f.read(), namespace)
+        self.clear()
+        self.update(namespace['_cocos_signals'])
+
 
 # cocos_signals is the actual dictionary
 cocos_signals = CocosSignals()
-cocos_signals.update(_cocos_signals)
